==> cactoos_0.48.orig.tar.gz: cactoos-0.48/src/main/java/org/cactoos/text/Lowered.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos.text;

import java.util.Locale;
import org.cactoos.Text;

/**
 * Text in lower case.
 *
 * <p>There is no thread-safety guarantee.
 *
 * @since 0.1
 */
public final class Lowered extends TextEnvelope {

    /**
     * Ctor.
     * @param text The text
     */
    public Lowered(final String text) {
        this(new TextOf(text));
    }

    /**
     * Ctor.
     * @param text The text
     */
    public Lowered(final Text text) {
        this(text, Locale.ENGLISH);
    }

    /**
     * Ctor.
     * @param text The text
     * @param locale The locale
     * @todo #1287:30min Introduce `text.Mapped` that takes a `Text` and
     *  a `Func` from `String` to `String`. Add some tests (included for
     *  `equals`). Once it is done, replace the code below by the use of
     *  `text.Mapped`. Do the same for all the one-liner mapping of the
     *  `text` package (e.g., `Upper`, `Trimmed`).
     */
    public Lowered(final Text text, final Locale locale) {
        super(new TextOf(() -> text.asString().toLowerCase(locale)));
    }
}

==> cactoos_0.49.orig.tar.gz: cactoos-0.49/src/main/java/org/cactoos/text/Lowered.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos.text;

import java.util.Locale;
import org.cactoos.Text;

/**
 * Text in lower case.
 *
 * <p>There is no thread-safety guarantee.
 *
 * @since 0.1
 */
public final class Lowered extends TextEnvelope {

    /**
     * Ctor.
     * @param text The text
     */
    public Lowered(final String text) {
        this(new TextOf(text));
    }

    /**
     * Ctor.
     * @param text The text
     */
    public Lowered(final Text text) {
        this(text, Locale.ENGLISH);
    }

    /**
     * Ctor.
     * @param text The text
     * @param locale The locale
     */
    public Lowered(final Text text, final Locale locale) {
        super(new Mapped(str -> str.toLowerCase(locale), text));
    }
}
